@echo off
REM
REM * ============================================================================
REM * Licensed Materials - Property of IBM
REM * Project  Zero
REM *
REM * (C) Copyright IBM Corp. 2007  All Rights Reserved.
REM *
REM * US Government Users Restricted Rights - Use, duplication or disclosure
REM * restricted by GSA ADP Schedule Contract with IBM Corp.
REM * ============================================================================
REM
@setlocal

rem initialization
set EXIT_CODE=0
set CLI_TASKS=
set KERNEL=

call :DEBUG_ECHO "zero.cli.tasks script, location is %CD%"

if not "%ZERO_HOME%"=="" goto check_javahome
rem ZERO_HOME must be set by the set up script
echo ZERO_HOME is not set
set EXIT_CODE=1
goto end

:check_javahome
if not "%_JAVACMD%"=="" goto check_apphome
rem _JAVACMD must be set by the set up script
echo _JAVACMD is not set
set EXIT_CODE=1
goto end

:check_apphome
set ZEROHOME_ZRP=%ZERO_HOME%\.zero\private\resolved.properties

rem if app_home is not set then use zerohome
if "%APP_HOME%" == "" goto check_zerohome

rem see if the apphome points to a resolved.properties with dependencies on z.c.t and
rem z.k. If not then we need to use zerohome for clitaskshome
                                            
set ZRP=%APP_HOME%\.zero\private\resolved.properties
if not exist "%ZRP%" goto check_zerohome

for /F "usebackq eol=; tokens=1,2* delims==" %%i in ("%ZRP%") do if %%i == zero.cli.tasks (set CLI_TASKS=%%j) else if %%i == zero.kernel (set KERNEL=%%j)

rem initialize cli_tasks_home to the value of app_home
set CLI_TASKS_HOME=%APP_HOME%

rem check zero.cli.tasks
if not "%CLI_TASKS%" == "" goto fix_cli_tasks_home_path
call :DEBUG_ECHO "zero.cli.tasks was not found in resolved properties"
set CLI_TASKS_HOME=
goto check_zerohome
     
:fix_cli_tasks_home_path     
set CLI_TASKS=%CLI_TASKS:\:=:%
set CLI_TASKS=%CLI_TASKS:\\=\%

if exist "%CLI_TASKS%" goto check_kernel
call :DEBUG_ECHO "zero.cli.tasks found in resolved properties does not exist"
set CLI_TASKS_HOME=
goto check_zerohome

rem check zero.kernel
:check_kernel
if not "%KERNEL%" == "" goto fix_kernel_path
call :DEBUG_ECHO "zero.kernel was not found in resolved properties"
set CLI_TASKS_HOME=
goto check_zerohome     

:fix_kernel_path
set KERNEL=%KERNEL:\:=:%
set KERNEL=%KERNEL:\\=\%

if exist "%KERNEL%" goto set_cli_zrp
call :DEBUG_ECHO "zero.kernel found in resolved properties does not exist"
set CLI_TASKS_HOME=

:check_zerohome  
if exist "%ZEROHOME_ZRP%" goto cli_tasks_home_is_zerohome
echo A valid resolved.properties does not exist either the current directory or %ZERO_HOME%
set EXIT_CODE=1
goto end

:cli_tasks_home_is_zerohome
set CLI_TASKS_HOME=%ZERO_HOME%

:set_cli_zrp
set CLI_ZRP=%CLI_TASKS_HOME%\.zero\private\resolved.properties

call :DEBUG_ECHO "get natives and classpath"

for /F "usebackq eol=; tokens=1,2* delims==" %%i in ("%CLI_ZRP%") do if %%i == classpath.cli (set CLASSPATH=%%j) else if %%i == natives (set NATIVES=%%j) else if %%i == classpath.cli.bootstrap (set CLASSPATH_CLI_BOOTSTRAP=%%j)

call :DEBUG_ECHO "check natives, %NATIVES%"
if "%NATIVES%" == "" goto check_classpath_cli_bootstrap
set NATIVES=%NATIVES:\:=:%
set NATIVES=%NATIVES:\\=\%

:check_classpath_cli_bootstrap
call :DEBUG_ECHO "check classpath.cli.bootstrap, %CLASSPATH_CLI_BOOTSTRAP%"
if "%CLASSPATH_CLI_BOOTSTRAP%" == "" goto check_classpath
set CLASSPATH=%CLASSPATH_CLI_BOOTSTRAP%
set CLASSPATH=%CLASSPATH:\:=:%
set CLASSPATH=%CLASSPATH:\\=\%
goto resolve_cli

:check_classpath
call :DEBUG_ECHO "check classpath.cli %CLASSPATH%"
if "%CLASSPATH%" == "" goto resolve_cli
set CLASSPATH=%CLASSPATH:\:=:%
set CLASSPATH=%CLASSPATH:\\=\%

:resolve_cli
rem if we don't have APP_HOME then the command is a cli task command
if "%APP_HOME%" == "" set APP_HOME=%CLI_TASKS_HOME%

if "%RESOLVE_CLI%" == "" goto run_command
rem if the command is for the cli and is an update ( or resolve) then skip resolve cli
if not "%APP_HOME%\." == "%ZERO_HOME%" goto call_resolve_cli
call :IS_UPDATE %*
rem errorlevel of 1 means the command is an update 
if errorlevel 1 goto run_command

:call_resolve_cli
call :DEBUG_ECHO "try to resolve the cli"
call :RESOLVE_CLI

:run_command
rem run the command
rem -apphome points to the resolved.properties that was found
call :DEBUG_ECHO "%_JAVACMD% %ZERO_OPTS% -classpath %CLASSPATH% -Djava.library.path=%NATIVES% zero.core.Main -apphome=%APP_HOME% -clitaskshome=%CLI_TASKS_HOME% %* %ZERO_ARGS%" 
"%_JAVACMD%" %ZERO_OPTS% -classpath "%CLASSPATH%" "-Djava.library.path=%NATIVES%" zero.core.Main -apphome="%APP_HOME%" -clitaskshome="%CLI_TASKS_HOME%" %* %ZERO_ARGS% 
set EXIT_CODE=%ERRORLEVEL% 

goto end

rem resolve new cli with cli.tasks
:RESOLVE_CLI
call :DEBUG_ECHO "resolve the cli, zerohome_zrp is %ZEROHOME_ZRP%" 
set RESOLVE_CLI_ERROR=0
for /F "usebackq eol=; tokens=1,2* delims==" %%i in ("%ZEROHOME_ZRP%") do if %%i == classpath.cli (set CLASSPATH=%%j)
if "CLASSPATH" == "" goto resolve_cli_no_classpath
set CLASSPATH=%CLASSPATH:\:=:%
set CLASSPATH=%CLASSPATH:\\=\%
"%_JAVACMD%" %ZERO_OPTS% -classpath "%CLASSPATH%" zero.core.Main -apphome="%ZERO_HOME%" -clitaskshome="%ZERO_HOME%" resolve"
if errorlevel 1 set RESOLVE_CLI_ERROR=1
goto resolve_cli_done
:resolve_cli_no_classpath
call :DEBUG_ECHO "could not find a classpath to resolve the cli"
set RESOLVE_CLI_ERROR=1
:resolve_cli_done
exit /b %RESOLVE_CLI_ERROR%
rem end of resolve_cli

rem check to see if update ( or resolve )
:IS_UPDATE
set IS_UPDATE_EXIT=0
:isUpdateCheckArgs
call :DEBUG_ECHO "check %1"
if ""%1""=="""" goto isUpdateDone
if ""%1""==""update"" goto isUpdateFound
if ""%1""==""resolve"" goto isUpdateFound
shift
goto isUpdateCheckArgs
:isUpdateFound
call :DEBUG_ECHO "task is update"
set IS_UPDATE_EXIT=1
:isUpdateDone

exit /b %IS_UPDATE_EXIT%
rem end of is update or resolve

rem debug echo
:DEBUG_ECHO
if not "%DEBUG%" == "" echo %1 1>&2
exit /b 0
rem end of debug echo

          
rem end of the script          
:end

exit /b %EXIT_CODE%
@endlocal